@@ -164,8 +164,8 @@ class JSProxyWidget(widgets.DOMWidget):
     _model_name = Unicode('JSProxyModel').tag(sync=True)
     _view_module = Unicode('jp_proxy_widget').tag(sync=True)
     _model_module = Unicode('jp_proxy_widget').tag(sync=True)
-    _view_module_version = Unicode('^1.0.8').tag(sync=True)
-    _model_module_version = Unicode('^1.0.8').tag(sync=True)
+    _view_module_version = Unicode('^1.0.9').tag(sync=True)
+    _model_module_version = Unicode('^1.0.9').tag(sync=True)
 
     # traitlet port to use for sending commands to javascript
     #commands = traitlets.List([], sync=True)
@@ -1466,17 +1466,25 @@ class LiteralMaker(CommandMaker):
 
     translators = {
         np.ndarray: np_array_to_list,
-        np.float: float,
-        np.float128: float,
-        np.float16: float,
-        np.float32: float,
-        np.float64: float,
-        np.int: int,
-        np.int0: int,
-        np.int16: int,
-        np.int32: int,
-        np.int64: int,
+        #np.float: float,
+        #np.float128: float,
+        #np.float16: float,
+        #np.float32: float,
+        #np.float64: float,
+        #np.int: int,
+        #np.int0: int,
+        #np.int16: int,
+        #np.int32: int,
+        #np.int64: int,
     }
+    for type_name in "float float128 float16 float32 float64".split():
+        if hasattr(np, type_name):
+            ty = getattr(np, type_name)
+            translators[ty] = float
+    for type_name in "int int0 int16 int32 int64".split():
+        if hasattr(np, type_name):
+            ty = getattr(np, type_name)
+            translators[ty] = int
 
     indicators = {
         # things we can translate
